# =============================================================================
# Pelote Custom Exceptions
# =============================================================================
#
class PeloteException(Exception):
    pass


class MissingPandasException(PeloteException):
    pass
